<?php
/**
 * @file
 * Contains all functionality handling stylesheets.
 */

/**
 * Implements hook_css_alter().
 *
 * Remove Drupal's core system stylesheets.
 * They aren't compatible with the Rijkshuisstijl starterskit library.
 */
function rijkshuisstijl_css_alter(&$css) {
  $exclude = array(
    'modules/system/system.base.css' => FALSE,
    'modules/system/system.menus.css' => FALSE,
    'modules/system/system.messages.css' => FALSE,
    'modules/system/system.theme.css' => FALSE,
  );

  if (module_exists('webform')) {
    $exclude[drupal_get_path('module', 'webform') . '/css/webform.css'] = FALSE;
  }

  $css = array_diff_key($css, $exclude);
}

/**
 * This functions includes all the starterkit library stylesheets.
 */
function rijkshuisstijl_add_stylesheets(&$variables) {
  $theme_path = path_to_theme();

  // Add conditional stylesheets for IE.
  drupal_add_css($theme_path . '/styles/ie/ie.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => TRUE,
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );

  drupal_add_css($theme_path . '/styles/ie/ie-7.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 7',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );

  drupal_add_css($theme_path . '/styles/ie/ie-8.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 8',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );
}
