<?php
/**
 * @file
 * Global functionality for the theme.
 */

$path_rijkshuisstijl = drupal_get_path('theme', 'rijkshuisstijl');
  include_once './' . $path_rijkshuisstijl . '/functions/form.php';
  include_once './' . $path_rijkshuisstijl . '/functions/menu.php';
  include_once './' . $path_rijkshuisstijl . '/functions/misc.php';
  include_once './' . $path_rijkshuisstijl . '/functions/pager.php';
  include_once './' . $path_rijkshuisstijl . '/functions/stylesheets.php';
  include_once './' . $path_rijkshuisstijl . '/functions/webform.php';

/**
 * Implements theme_breadcrumb().
 *
 * Replaced › character by > character.
 */
function rijkshuisstijl_breadcrumb($variables) {
  $breadcrumb = $variables['breadcrumb'];

  if (!empty($breadcrumb)) {
    $title = drupal_get_title();

    if (!empty($title)) {
      $breadcrumb[] = $title;

      if (strip_tags($breadcrumb[(count($breadcrumb) - 2)]) == $breadcrumb[count($breadcrumb) - 1]) {
        unset($breadcrumb[(count($breadcrumb) - 2)]);
      }
    }

    return '<div class="breadcrumb"><p><em>' . t('You are here') . ': </em>' . implode('<span class="imgreplacement"> &#8250; </span>', $breadcrumb) . '</p></div>';
  }
}

/**
 * Implements hook_item_list().
 *
 * Removed wrapping <div>
 * Rename .first and .last class from item-list by default
 */
function rijkshuisstijl_item_list($variables) {
  $items = $variables['items'];
  $title = $variables['title'];
  $type = $variables['type'];
  $attributes = $variables['attributes'];

  $output = '';
  if (isset($title)) {
    $output .= '<h3>' . $title . '</h3>';
  }

  if (!empty($items)) {
    $output .= "<$type" . drupal_attributes($attributes) . '>';
    $num_items = count($items);

    foreach ($items as $i => $item) {
      $attributes = array();
      $children = array();
      $data = '';

      if (is_array($item)) {
        foreach ($item as $key => $value) {
          if ($key == 'data') {
            $data = $value;
          }
          elseif ($key == 'children') {
            $children = $value;
          }
          else {
            $attributes[$key] = $value;
          }
        }
      }
      else {
        $data = $item;
      }

      if (count($children) > 0) {
        // Render nested list.
        $data .= theme_item_list(array(
          'items' => $children,
          'title' => NULL,
          'type' => $type,
          'attributes' => $attributes,
        ));
      }

      if ($i == 0) {
        $attributes['class'][] = 'first-item';
      }

      if ($i == $num_items - 1) {
        $attributes['class'][] = 'last-item';
      }

      $output .= '<li' . drupal_attributes($attributes) . '>' . $data . "</li>\n";
    }

    $output .= "</$type>";
  }

  $output .= '';
  return $output;
}

/**
 * Implements hook_libraries_info().
 */
function rijkshuisstijl_libraries_info() {
  $libraries['starterskit'] = array(
    'name' => 'Starterskit',
    'vendor url' => 'http://rijkshuisstijl.nl/',
    'download url' => 'https://github.com/studiodumbar/starterskit-pb/zipball/1.2.3',
    'version arguments' => array(
      'file' => 'README.txt',
      'pattern' => '/^versie\s+([[0-9\.]+)/',
      'lines' => 60,
      'cols' => 30,
    ),
    'files' => array(
      'css' => array(
        'css/screen.css' => array(
          'type' => 'file',
          'group' => CSS_THEME,
          'every_page' => TRUE,
          'preprocess' => TRUE,
          'media' => 'screen',
          'weight' => -100,
        ),
        'css/ie/ie6.css' => array(
          'type' => 'file',
          'group' => CSS_THEME,
          'every_page' => TRUE,
          'preprocess' => TRUE,
          'media' => 'screen',
          'weight' => -100,
          'browsers' => array(
            'IE' => 'lte IE 6',
            '!IE' => FALSE,
          ),
        ),
        'css/ie/ie7.css' => array(
          'type' => 'file',
          'group' => CSS_THEME,
          'every_page' => TRUE,
          'preprocess' => TRUE,
          'media' => 'screen',
          'weight' => -100,
          'browsers' => array(
            'IE' => 'lte IE 7',
            '!IE' => FALSE,
          ),
        ),
        'css/ie/ie8.css' => array(
          'type' => 'file',
          'group' => CSS_THEME,
          'every_page' => TRUE,
          'preprocess' => TRUE,
          'media' => 'screen',
          'weight' => -100,
          'browsers' => array(
            'IE' => 'lte IE 8',
            '!IE' => FALSE,
          ),
        ),
        'css/print.css' => array(
          'type' => 'file',
          'group' => CSS_THEME,
          'every_page' => TRUE,
          'preprocess' => TRUE,
          'media' => 'print',
          'weight' => -100,
        ),
      ),
    ),
  );

  return $libraries;
}

/**
 * Implements theme_link().
 *
 * Override links to add an 'external' class if needed.
 *
 * Only adds the external class to external links that
 * don't contain an image.
 */
function rijkshuisstijl_link($variables) {
  global $base_url;
  if (
    // Is the URL absolute?
    url_is_external($variables['path']) &&
    // The site url is not part of the path.
    strstr($variables['path'], $base_url) === FALSE &&
    // The link does not contain an image (to prevent double images).
    strstr($variables['text'], '<img ') === FALSE
  ) {
    $variables['options']['attributes']['class'][] = 'external';
    $variables['options']['html'] = TRUE;

    if (isset($variables['options']['attributes']['title'])) {
      $title = &$variables['options']['attributes']['title'];
      $title = t('External site: @title', array('@title' => $title));
    }
    else {
      $variables['options']['attributes']['title'] = t('External site');
    }
  }
  return '<a href="' . check_plain(url($variables['path'], $variables['options'])) . '"' . drupal_attributes($variables['options']['attributes']) . '>' . ($variables['options']['html'] ? $variables['text'] : check_plain($variables['text'])) . '</a>';
}

/**
 * Implements hook_preprocess().
 */
function rijkshuisstijl_preprocess(&$variables, $hook) {
  $variables['starterskit'] = _rijkshuisstijl_init_starterskit();
}

/**
 * Implements hook_preprocess_html().
 */
function rijkshuisstijl_preprocess_html(&$variables) {
  _rijkshuisstijl_render_doctype($variables);

  // Append the system_type class to the body classes.
  $variables['classes_array'][] = theme_get_setting('system_type');

  if (drupal_is_front_page()) {
    $variables['attributes_array']['id'] = 'home';
  }
  elseif ('user/login' === current_path() || 'user/password' === current_path()) {
    $variables['attributes_array']['id'] = 'login';
  }
  else {
    $variables['attributes_array']['id'] = 'content';
  }

  rijkshuisstijl_add_stylesheets($variables);

  // Create menu.
  $menus = array(
    'menu-service-menu-right' => array(
      'menu_name' => 'menu-service-menu-right',
      'title' => 'Service menu right',
      'description' => 'Service menu appears in the upper right corner of the page.',
    ),
    'menu-footer-menu-right' => array(
      'menu_name' => 'menu-footer-menu-right',
      'title' => 'Footer menu right',
      'description' => 'Footer menu appears in the lower right corner of the page.',
    ),
    'menu-search-menu' => array(
      'menu_name' => 'menu-search-menu',
      'title' => 'Search menu',
      'description' => 'Search menu appears beneath the search box.',
    ),
  );

  // Check if the menu module is actived.
  if (module_exists('menu')) {
    foreach ($menus as $menu_name => $menu_data) {
      // Checks if menu already exists.
      if (!menu_load($menu_name)) {
        // Create service menu left.
        menu_save($menu_data);
      }
    }
  }
}

/**
 * Implements template_preprocess_maintenance_page().
 */
function rijkshuisstijl_preprocess_maintenance_page(&$variables) {
  _rijkshuisstijl_render_doctype($variables);
  _rijkshuisstijl_render_titlebar($variables);

  // Append the system_type class to the body classes.
  $variables['classes_array'][] = theme_get_setting('system_type');
  // Add the content ID to the body attributes.
  $variables['attributes_array']['id'] = 'content';

  rijkshuisstijl_add_stylesheets($variables);
}

/**
 * Implements template_preprocess_page().
 */
function rijkshuisstijl_preprocess_page(&$variables) {
  $variables['classes_array'][] = theme_get_setting('color_swatch');
  $variables['classes_array'][] = theme_get_setting('system_width');

  _rijkshuisstijl_render_titlebar($variables);
}

/**
 * Implements hook_preprocess_search_result().
 *
 * Adding type as meta data in search results.
 */
function rijkshuisstijl_preprocess_search_result(&$variables) {
  global $language;

  $result = $variables['result'];
  $variables['url'] = check_url($result['link']);
  $variables['title'] = check_plain($result['title']);
  if (isset($result['language']) && $result['language'] != $language->language && $result['language'] != LANGUAGE_NONE) {
    $variables['title_attributes_array']['xml:lang'] = $result['language'];
    $variables['content_attributes_array']['xml:lang'] = $result['language'];
  }

  $info = array();
  if (!empty($result['module'])) {
    $info['module'] = check_plain($result['module']);
  }

  if (!empty($result['type'])) {
    $info['type'] = check_plain($result['type']);
  }

  if (!empty($result['user'])) {
    $info['user'] = $result['user'];
  }

  if (!empty($result['date'])) {
    $info['date'] = format_date($result['date'], 'custom', 'j F Y');
  }

  if (isset($result['extra']) && is_array($result['extra'])) {
    $info = array_merge($info, $result['extra']);
  }

  // Check for existence. User search does not include snippets.
  $variables['snippet'] = isset($result['snippet']) ? $result['snippet'] : '';
  // Provide separated and grouped meta information..
  $variables['info_split'] = $info;
  $variables['info'] = implode(' - ', $info);
  $variables['theme_hook_suggestions'][] = 'search_result__' . $variables['module'];
}

/**
 * Implements hook_preprocess_search_results().
 *
 * Adding a search count above the search results
 */
function rijkshuisstijl_preprocess_search_results(&$variables) {
  // Extract keys as remainder of path
  // Note: support old GET format of searches for existing links.
  $path = explode('/', $_GET['q'], 3);
  $keys = empty($_REQUEST['keys']) ? '' : $_REQUEST['keys'];
  $keys = count($path) == 3 ? $path[2] : $keys;

  if (isset($GLOBALS['pager_total_items'])) {
    // Define the number of results being shown on a page.
    $items_per_page = 10;
    $current_page = 1;

    // Get the current page.
    if (isset($_REQUEST['page'])) {
      $current_page = $_REQUEST['page'] + 1;
    }

    // Get the total number of results from the $GLOBALS.
    $total = $GLOBALS['pager_total_items'][0];

    // Perform calculation.
    $start = 10 * $current_page - 9;
    $end = $items_per_page * $current_page;
    if ($end > $total) {
      $end = $total;
    }

    // Set this html to the $variables.
    $variables['rijkshuisstijl_search_totals'] = t('<p><strong>@total results for ‘<em>@keys</em>’…</strong>', array(
      '@start' => $start,
      '@end' => $end,
      '@total' => $total,
      '@keys' => $keys,
    ));
  }
  else {
    $variables['rijkshuisstijl_search_totals'] = '';
  }
}

/**
 * Implements theme_status_messages().
 *
 * Replace classes for messages.
 */
function rijkshuisstijl_status_messages($variables) {
  $display = $variables['display'];
  $output = '';
  $status_heading = array(
    'status'  => t('Status message'),
    'error'   => t('Error message'),
    'warning'   => t('Warning message'),
  );

  foreach (drupal_get_messages($display) as $type => $messages) {
    $typeextra = $type;
    if ($type == 'error') {
      $typeextra = 'message_err';
    }
    elseif ($type == 'warning') {
      $typeextra = 'message_info';
    }

    // Check if theme setting 'System type' is set to 'internet'
    // which always has a sidebar right.
    if (theme_get_setting('system_type') == 'internet') {
      $output .= "<div class=\"$typeextra\">\n";
    }
    else {
      $output .= "<div class=\"mod $typeextra\">\n";
    }

    if (!empty($status_heading[$type])) {
      $output .= '<h2>' . $status_heading[$type] . "</h2>\n";
    }

    if (count($messages) > 1) {
      $output .= " <ul>\n";

      foreach ($messages as $message) {
        $output .= '  <li><p>' . $message . "</p></li>\n";
      }

      $output .= " </ul>\n";
    }
    else {
      $output .= '<p>' . $messages[0] . '</p>';
    }

    $output .= "</div>\n";
  }

  return $output;
}

/**
 * Implements theme_file_icon().
 */
function rijkshuisstijl_file_icon($variables) {
  // Removing default Drupal file-icon image.
  return '';
}

/**
 * Implements theme_file_link().
 */
function rijkshuisstijl_file_link($variables) {
  // Removing redundant <span class="file"> tag.
  $file = $variables['file'];
  $icon_directory = $variables['icon_directory'];

  $url = file_create_url($file->uri);
  $icon = theme('file_icon', array(
    'file' => $file,
    'icon_directory' => $icon_directory,
  ));

  // Set options as per anchor format described at
  // http://microformats.org/wiki/file-format-examples.
  $options = array(
    'attributes' => array(
      'type' => $file->filemime . '; length=' . $file->filesize,
    ),
  );

  // Use the description as the link text if available.
  if (empty($file->description)) {
    $link_text = $file->filename;
  }
  else {
    $link_text = $file->description;
    $options['attributes']['title'] = check_plain($file->filename);
  }

  return $icon . ' ' . l($link_text, $url, $options);
}

/**
 * Renders the DOCTYPE and html element.
 */
function _rijkshuisstijl_render_doctype(&$variables) {
  $variables['doctype'] = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">";
  $variables['html'] = "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"" . $variables['language']->language . "\" lang=\"" . $variables['language']->language . "\">";
  // Modify the doctype and html element if the rdf module is enabled.
  if (module_exists('rdf')) {
    $variables['doctype'] = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML+RDFa 1.0//EN\" \"http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd\">";
    $variables['html']  = "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"" . $variables['language']->language . "\" version=\"XHTML+RDFa 1.0\" dir=\"" . $variables['language']->dir . "\" " . $variables['rdf_namespaces'] . "\n>\n";
  }
}

/**
 * Renders the correct data in the titlebar.
 */
function _rijkshuisstijl_render_titlebar(&$variables) {
  // If default_titlebar is checked, replace the titlebar title and slogan
  // with the global site name and slogan.
  if (theme_get_setting('default_titlebar')) {
    $variables['titlebar_title'] = $variables['site_name'];
    $variables['titlebar_slogan'] = $variables['site_slogan'];
  }
  else {
    $variables['titlebar_title'] = theme_get_setting('titlebar_title');
    $variables['titlebar_slogan'] = theme_get_setting('titlebar_slogan');
  }

  // @todo Check if this can become prettier.
  if (drupal_is_front_page() && theme_get_setting('default_titlebar')) {
    $variables['title_bar_name_element'] = 'h1';
    $variables['site_name_element'] = 'div';
  }
  elseif (drupal_is_front_page() && theme_get_setting('default_titlebar')) {
    $variables['title_bar_name_element'] = 'div';
    $variables['site_name_element'] = 'h1';
  }
  else {
    $variables['title_bar_name_element'] = 'div';
    $variables['site_name_element'] = 'div';
  }
}
