<?php
/**
 * @file
 * Default theme implementation to display the basic html structure of a single
 * Drupal page.
 *
 * Variables:
 * - $css: An array of CSS files for the current page.
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction.
 *   It will either be 'ltr' or 'rtl'.
 * - $rdf_namespaces: All the RDF namespace prefixes used in the HTML document.
 * - $grddl_profile: A GRDDL profile allowing agents to extract the RDF data.
 * - $head_title: A modified version of the page title, for use in the TITLE
 *   tag.
 * - $head_title_array: (array) An associative array containing the string parts
 *   that were used to generate the $head_title variable, already prepared to be
 *   output as TITLE tag. The key/value pairs may contain one or more of the
 *   following, depending on conditions:
 *   - title: The title of the current page, if any.
 *   - name: The name of the site.
 *   - slogan: The slogan of the site, if any, and if there is no title.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $page_top: Initial markup from any modules that have altered the
 *   page. This variable should always be output first, before all other dynamic
 *   content.
 * - $page: The rendered page content.
 * - $page_bottom: Final closing markup from any modules that have altered the
 *   page. This variable should always be output last, after all other dynamic
 *   content.
 * - $classes String of classes that can be used to style contextually through
 *   CSS.
 *
 * @see template_preprocess()
 * @see template_preprocess_html()
 * @see template_process()
 *
 * @ingroup themeable
 */

global $base_url;

// Print the DOCTYPE and html element.
print $doctype . "\n" . $html;
?>
  <head profile="<?php print $grddl_profile; ?>">
    <meta http-equiv="content-type" content="text/html;charset=UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />
    <meta name="viewport" content="width=device-width,initial-scale=1" />
    <?php
      // -- For non-Retina iPhone, iPod Touch, and Android 2.1+ devices: ?>
      <link rel="apple-touch-icon-precomposed" href="<?php printf('%s/%s/images/apple-touch-icon-precomposed.png', $base_url, path_to_theme()); ?>" />
    <?php
      // -- For nokia devices: ?>
      <link rel="shortcut icon" href="<?php printf('%s/%s/images/apple-touch-icon.png', $base_url, path_to_theme()); ?>"/>
    <?php
      // -- For webbrowsers: ?>
      <link rel="shortcut icon" href="<?php printf('%s/%s/favicon.ico', $base_url, $starterskit['library path']); ?>" type="image/vnd.microsoft.icon" />
    <?php
      // -- Mobile IE allows us to activate ClearType technology
      // for smoothing fonts for easy reading.
    ?>
    <meta http-equiv="cleartype" content="on" />
    <?php print $head; ?>
    <title><?php print $head_title; ?></title>
    <?php print $styles; ?>
    <?php print $scripts; ?>
  </head>

  <body class="<?php print $classes; ?>" <?php print $attributes;?>>
    <ul class="skiplink">
      <li><a href="#hoofd_content" title="<?php print t('Skip to content'); ?>"><?php print t('Skip to content'); ?></a></li>
      <li><a href="#service_menu" title="<?php print t('Skip to service menu'); ?>"><?php print t('Skip to service menu'); ?></a></li>
      <li><a href="#zoeken" title="<?php print t('Skip to search'); ?>"><?php print t('Skip to search'); ?></a></li>
    </ul>
    <?php print $page_top; ?>
    <?php print $page; ?>
    <?php print $page_bottom; ?>
  </body>
</html>
